You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cloudstack.apache.org by ml...@apache.org on 2013/01/18 23:23:43 UTC

[39/50] [abbrv] git commit: Summary: Pass StoragePoolType that maps to libvirt in cleanupDisk

Summary: Pass StoragePoolType that maps to libvirt in cleanupDisk

Description: When selecting a storage adaptor, cleanupDisk assumes that
libvirt is being used. Therefore, we pass a StoragePoolType that maps to
libvirt. This is the only place in LibvirtComputingResource where the
StoragePoolType can't be pulled from somewhere else.

BUG-ID: CLOUDSTACK-1011
Signed-off-by: Marcus Sorensen <ma...@betterservers.com>


Project: http://git-wip-us.apache.org/repos/asf/incubator-cloudstack/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-cloudstack/commit/55e8965b
Tree: http://git-wip-us.apache.org/repos/asf/incubator-cloudstack/tree/55e8965b
Diff: http://git-wip-us.apache.org/repos/asf/incubator-cloudstack/diff/55e8965b

Branch: refs/heads/add_remove_nics
Commit: 55e8965bd0386099a101362e0dc87f3dc2a0aa9d
Parents: a0bc508
Author: Marcus Sorensen <ma...@betterservers.com>
Authored: Fri Jan 18 00:20:34 2013 -0700
Committer: Marcus Sorensen <ma...@betterservers.com>
Committed: Fri Jan 18 00:20:34 2013 -0700

----------------------------------------------------------------------
 .../kvm/resource/LibvirtComputingResource.java     |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-cloudstack/blob/55e8965b/plugins/hypervisors/kvm/src/com/cloud/hypervisor/kvm/resource/LibvirtComputingResource.java
----------------------------------------------------------------------
diff --git a/plugins/hypervisors/kvm/src/com/cloud/hypervisor/kvm/resource/LibvirtComputingResource.java b/plugins/hypervisors/kvm/src/com/cloud/hypervisor/kvm/resource/LibvirtComputingResource.java
index b65b531..eac60f4 100755
--- a/plugins/hypervisors/kvm/src/com/cloud/hypervisor/kvm/resource/LibvirtComputingResource.java
+++ b/plugins/hypervisors/kvm/src/com/cloud/hypervisor/kvm/resource/LibvirtComputingResource.java
@@ -3225,8 +3225,11 @@ public class LibvirtComputingResource extends ServerResourceBase implements
         }
 
         try {
-            //we use libvirt since we passed a libvirt connection to cleanupDisk
-            KVMStoragePool pool = _storagePoolMgr.getStoragePool(null, poolUuid);
+            // we use libvirt as storage adaptor since we passed a libvirt
+            // connection to cleanupDisk. We pass a storage type that maps
+            // to libvirt adaptor.
+            KVMStoragePool pool = _storagePoolMgr.getStoragePool(
+                                      StoragePoolType.Filesystem, poolUuid);
             if (pool != null) {
                 pool.delete();
             }